
## Release Notes

**v2.1.3 - June 5, 2020**

**refactor**: stop sherlock checking for transient database triggers if running in non-update mode
**fixed**: another sdss photoz issue where photoz ranking about specz

**v2.1.2 - May 24, 2020**

* **fixed:** merged result parameters are now merged correctly

**v2.1.1 - May 21, 2020**

* **fixed:** fixes to cl utils

**v2.1.0 - May 20, 2020**

* Now compatible with Python 3.*
